<!-- -*- mode: markdown; mode: flyspell -*- -->

# bash-range-expand library

A simple library to expand numeric ranges. A range are two numbers
separated by a dash. E.g. "10-12" would expand to "10 11 12". It
supports macros which enables to use names for ranges. Any strings
that are no ranges will be copied. Expansion can be extended with
prefixes and suffixes, which will only be added to ranges or numbers.
Macros are read from an associative array called
BRB_RANGE_MACROS. This will change in the future.

This library has only one API function and it exists mainly because it
is used on different places.

## Dependencies

bash-range-expand depends on bash-base

## API Documentation

The API Documentation can be found in [API.md](API.md).

## Using bash-range-expand

### Loading the Library

With loaded bash-base and system wide installed bash-range-expand all
you have to do is:
```
bb_require_libs bash-range-expand
```

Note: Using `bb_require_libs` will raise an fatal error if the library
could not be loaded. Use e.g. `bb_load_lib` to react on any error
while loading it.

## Namespace

All global variables and functions of bash-yaml start with either
`byml_` or `_byml_`. Functions starting with `_byml_` are for
internal use only and their API might change without warning.

Function that take variable names as arguments will not accept
variable names starting with `_`. Local variables in bash-yaml
function will always start with `_` or with the full function
name. That ensures that passed variable names will not be shadowed by
local variables inside the called function.

## Examples

```bash
> brp_expand_ranges "" "" "" 1 2 3
1 2 3

> brp_expand_ranges "pre" "post" "" 1 2 3 
pre1post pre2post pre3post

> brp_expand_ranges "" "post" "" 1-3
1post 2post 3post

> brp_expand_ranges "" "post" "" 1-3 somestring 3
1post 2post 3post somestring 3post

BRB_RANGE_MACROS=([cow]=1-3 [cat]=2-5

> brp_expand_ranges "" "" "" cow
1 2 3

> brp_expand_ranges "" "" "" cat cow
2 3 4 5 1 2 3

BRB_RANGE_MACROS=([cow1]="1-3" [cow2]="4-5" [herd]="cow1 cow2")

> brp_expand_ranges "mooh" "" "" herd
mooh1 mooh2 mooh3 mooh4 mooh5
```
